==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ApplicationStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ApplicationStatusFluent<A extends ApplicationStatusFluent<A>> extends Fluent<A>{
  public A addToComponents(Integer index,ObjectStatus item);
  public A setToComponents(Integer index,ObjectStatus item);
  public A addToComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... items);
  public A addAllToComponents(Collection<ObjectStatus> items);
  public A removeFromComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... items);
  public A removeAllFromComponents(Collection<ObjectStatus> items);
  public A removeMatchingFromComponents(Predicate<ObjectStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObjectStatus> getComponents();
  public List<ObjectStatus> buildComponents();
  public ObjectStatus buildComponent(Integer index);
  public ObjectStatus buildFirstComponent();
  public ObjectStatus buildLastComponent();
  public ObjectStatus buildMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public Boolean hasMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public A withComponents(List<ObjectStatus> components);
  public A withComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... components);
  public Boolean hasComponents();
  public A addNewComponent(String group,String kind,String link,String name,String status);
  public ApplicationStatusFluent.ComponentsNested<A> addNewComponent();
  public ApplicationStatusFluent.ComponentsNested<A> addNewComponentLike(ObjectStatus item);
  public ApplicationStatusFluent.ComponentsNested<A> setNewComponentLike(Integer index,ObjectStatus item);
  public ApplicationStatusFluent.ComponentsNested<A> editComponent(Integer index);
  public ApplicationStatusFluent.ComponentsNested<A> editFirstComponent();
  public ApplicationStatusFluent.ComponentsNested<A> editLastComponent();
  public ApplicationStatusFluent.ComponentsNested<A> editMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public String getComponentsReady();
  public A withComponentsReady(String componentsReady);
  public Boolean hasComponentsReady();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... conditions);
  public Boolean hasConditions();
  public ApplicationStatusFluent.ConditionsNested<A> addNewCondition();
  public ApplicationStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ApplicationStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public ApplicationStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ApplicationStatusFluent.ConditionsNested<A> editFirstCondition();
  public ApplicationStatusFluent.ConditionsNested<A> editLastCondition();
  public ApplicationStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface ComponentsNested<N> extends Nested<N>,ObjectStatusFluent<ApplicationStatusFluent.ComponentsNested<N>>{
    public N and();
    public N endComponent();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ApplicationStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ApplicationStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ApplicationStatusFluent<A extends ApplicationStatusFluent<A>> extends Fluent<A>{
  public A addToComponents(int index,ObjectStatus item);
  public A setToComponents(int index,ObjectStatus item);
  public A addToComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... items);
  public A addAllToComponents(Collection<ObjectStatus> items);
  public A removeFromComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... items);
  public A removeAllFromComponents(Collection<ObjectStatus> items);
  public A removeMatchingFromComponents(Predicate<ObjectStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildComponents instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ObjectStatus> getComponents();
  public List<ObjectStatus> buildComponents();
  public ObjectStatus buildComponent(int index);
  public ObjectStatus buildFirstComponent();
  public ObjectStatus buildLastComponent();
  public ObjectStatus buildMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public Boolean hasMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public A withComponents(List<ObjectStatus> components);
  public A withComponents(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ObjectStatus... components);
  public Boolean hasComponents();
  public A addNewComponent(String group,String kind,String link,String name,String status);
  public ApplicationStatusFluent.ComponentsNested<A> addNewComponent();
  public ApplicationStatusFluent.ComponentsNested<A> addNewComponentLike(ObjectStatus item);
  public ApplicationStatusFluent.ComponentsNested<A> setNewComponentLike(int index,ObjectStatus item);
  public ApplicationStatusFluent.ComponentsNested<A> editComponent(int index);
  public ApplicationStatusFluent.ComponentsNested<A> editFirstComponent();
  public ApplicationStatusFluent.ComponentsNested<A> editLastComponent();
  public ApplicationStatusFluent.ComponentsNested<A> editMatchingComponent(Predicate<ObjectStatusBuilder> predicate);
  public String getComponentsReady();
  public A withComponentsReady(String componentsReady);
  public Boolean hasComponentsReady();
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.Condition... conditions);
  public Boolean hasConditions();
  public ApplicationStatusFluent.ConditionsNested<A> addNewCondition();
  public ApplicationStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ApplicationStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public ApplicationStatusFluent.ConditionsNested<A> editCondition(int index);
  public ApplicationStatusFluent.ConditionsNested<A> editFirstCondition();
  public ApplicationStatusFluent.ConditionsNested<A> editLastCondition();
  public ApplicationStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface ComponentsNested<N> extends Nested<N>,ObjectStatusFluent<ApplicationStatusFluent.ComponentsNested<N>>{
    public N and();
    public N endComponent();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ApplicationStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
